﻿using System.Web.Mvc;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

namespace MapMvc.Controllers
{
    [HandleError]
    public class MapController : Controller, IMapInitializer
    {
        public void SetupInitializer()
        {
            MapInitializerHelper.GetInstance().SetInitializer(this);
        }

        public ActionResult RefinerMap()
        {
            return View();
        }

        public void InitializeMap(ThinkGeo.MapSuite.WebEdition.Map map)
        {
            map.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.StandardColors.White);
            map.CurrentExtent = new RectangleShape(-131.22, 55.05, -54.03, 16.91);
            map.MapUnit = GeographyUnit.DecimalDegree;

            WorldMapKitWmsWebOverlay worldMapKitOverlay = new WorldMapKitWmsWebOverlay();
            map.CustomOverlays.Add(worldMapKitOverlay);

            string tempPath = System.AppDomain.CurrentDomain.BaseDirectory.TrimEnd('\\');
            string fullPath = tempPath + "\\App_Data\\STATES.SHP";
            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(fullPath);
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Transparent, GeoColor.FromArgb(100, GeoColor.SimpleColors.Green));
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            LayerOverlay staticOverlay = new LayerOverlay();
            staticOverlay.Layers.Add(worldLayer);
            staticOverlay.IsBaseOverlay = false;
            map.CustomOverlays.Add(staticOverlay);
        }
    }
}
